# Voxel

Core utilities for volumetric (3D) medical image analysis, written in pytorch. Voxel provides methods for working with image grid data and triangular meshes, with consideration of their representation in a world (or scanner) coordinate system. The toolbox is fully GPU compatible and developed with particular emphasis on its use for deep-learning applications. More documentation to come soon!

Voxel can be installed with:

```
pip install voxel
```

If you find this package useful in your work, please cite the following publication (for which this package was originally developed).
> [VoxelPrompt: A Vision Agent for End-to-End Medical Image Analysis](https://arxiv.org/abs/2410.08397)<br>
> Andrew Hoopes, Neel Dey, Victor Ion Butoi, John V. Guttag, Adrian V. Dalca
